==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/avfoundation/AVVideoCompositing.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.avfoundation;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.corefoundation.*;
import org.robovm.apple.dispatch.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coreaudio.*;
import org.robovm.apple.coremedia.*;
import org.robovm.apple.corevideo.*;
import org.robovm.apple.mediatoolbox.*;
import org.robovm.apple.audiotoolbox.*;
import org.robovm.apple.audiounit.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @since Available in iOS 7.0 and later.
 */
/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ interface /*<name>*/AVVideoCompositing/*</name>*/ 
    /*<implements>*/extends NSObjectProtocol/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<properties>*/
    @WeaklyLinked
    @Property(selector = "sourcePixelBufferAttributes")
    CVPixelBufferAttributes getSourcePixelBufferAttributes();
    @WeaklyLinked
    @Property(selector = "requiredPixelBufferAttributesForRenderContext")
    CVPixelBufferAttributes getRequiredPixelBufferAttributesForRenderContext();
    /*</properties>*/
    /*<methods>*/
    @Method(selector = "renderContextChanged:")
    void renderContextChanged(AVVideoCompositionRenderContext newRenderContext);
    @Method(selector = "startVideoCompositionRequest:")
    void startVideoCompositionRequest(AVAsynchronousVideoCompositionRequest asyncVideoCompositionRequest);
    @Method(selector = "cancelAllPendingVideoCompositionRequests")
    void cancelAllPendingVideoCompositionRequests();
    /*</methods>*/
    /*<adapter>*/
    /*</adapter>*/
}

==> robovm-cocoatouch-2.3.16-sources.jar: org/robovm/apple/avfoundation/AVVideoCompositing.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.avfoundation;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.corefoundation.*;
import org.robovm.apple.dispatch.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coreaudio.*;
import org.robovm.apple.coremedia.*;
import org.robovm.apple.corevideo.*;
import org.robovm.apple.mediatoolbox.*;
import org.robovm.apple.audiotoolbox.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ interface /*<name>*/AVVideoCompositing/*</name>*/ 
    /*<implements>*/extends NSObjectProtocol/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<properties>*/
    @WeaklyLinked
    @Property(selector = "sourcePixelBufferAttributes")
    CVPixelBufferAttributes getSourcePixelBufferAttributes();
    @WeaklyLinked
    @Property(selector = "requiredPixelBufferAttributesForRenderContext")
    CVPixelBufferAttributes getRequiredPixelBufferAttributesForRenderContext();
    /**
     * @since Available in iOS 10.0 and later.
     */
    @Property(selector = "supportsWideColorSourceFrames")
    boolean supportsWideColorSourceFrames();
    /**
     * @since Available in iOS 14.0 and later.
     */
    @Property(selector = "supportsHDRSourceFrames")
    boolean supportsHDRSourceFrames();
    /**
     * @since Available in iOS 15.0 and later.
     */
    @Property(selector = "canConformColorOfSourceFrames")
    boolean canConformColorOfSourceFrames();
    /*</properties>*/
    /*<methods>*/
    @Method(selector = "renderContextChanged:")
    void renderContextChanged(AVVideoCompositionRenderContext newRenderContext);
    @Method(selector = "startVideoCompositionRequest:")
    void startVideoCompositionRequest(AVAsynchronousVideoCompositionRequest asyncVideoCompositionRequest);
    @Method(selector = "cancelAllPendingVideoCompositionRequests")
    void cancelAllPendingVideoCompositionRequests();
    /**
     * @since Available in iOS 13.0 and later.
     */
    @Method(selector = "anticipateRenderingUsingHint:")
    void anticipateRenderingUsingHint(AVVideoCompositionRenderHint renderHint);
    /**
     * @since Available in iOS 13.0 and later.
     */
    @Method(selector = "prerollForRenderingUsingHint:")
    void prerollForRenderingUsingHint(AVVideoCompositionRenderHint renderHint);
    /*</methods>*/
    /*<adapter>*/
    /*</adapter>*/
}
